#!/bin/bash
############################################################
# This Shell script and the embeded GrADS Script are used to
# Download CFSv2 Forecast Data for domain of your interest and
# Plots Week-2 Precip/ T2m and Circulation Anomaly Forecasts
# Written by Endalkachew Bekele, NOAA/CPC/International Desks, August 2019

LANG=en_US.utf8

if [ "$#" -ne 4 ]; then
    echo "***************************************************************************************************************************"
    echo " error while running plot_cfsv2_week2_anomalies.sh"
    echo "----------------- You need to provide 4 arguments -------------------------------------------------------------------------"
    echo "***************************************************************************************************************************"
    echo
    echo "The four arguments reflect geographical extent of your area:"
    echo
    echo "western lon, eastern lon, southern lat and northern lat in degreas, respectively"
    echo
    echo "Use negative sign for longitudes in western, and latitudes in the southern hemisphere"
    echo
    echo "For example, if your area extends from 10W to 12E and from 5S to 10N .."
    echo " you may run the script as .."
    echo
    echo " ./plot_cfsv2_week2_anomalies.sh -10 12 -5 10"
    echo
    echo
exit
fi

# This sets current date for CFSv2 data Download
dt=`date +%Y%m%d`
dtt=`date +%d%b%Y`

for var in 'precip'; do

wget --no-check-certificate https://ftp.cpc.ncep.noaa.gov/International/subseasonal/gefs_week2_${var}_${dt}IC.dat

done


##### Define your domain here#####
west=$1
east=$2
south=$3
north=$4
########################333

# This extends the domain area by 1 degree for horizontal divergence calculation
let west1=$west-4
let east1=$east+4
let south1=$south-4
let north1=$north+4

let west2=$west-3
let east2=$east+3
let south2=$south-3
let north2=$north+3


# This calculates the number of grids in the zomnla and meridional directions
let dxx=$east1-$west1+1
let dyy=$north1-$south1+1


#gribmapdir=/cpc/home/ebekele/opg2/grads-2.0.1.oga.1/Contents

cat>gefs_week2_precip_${dt}IC.ctl<<eofctl
dset ^gefs_week2_precip_${dt}IC.dat
undef -999000000.000000
xdef 360 linear 0 1
ydef 181 linear -90 1
zdef 1 linear 1 1
tdef 1 linear ${dtt} 1dy
vars 4
clim 0 99 7-day climatology
total 0 99 7-day toatl Fcst
rawabv 0 99 Above Prob Raw fcst
calibabv 0 99 Above prob Calib fcst
endvars
eofctl

cat>plot_blank_map.gs<<eofGS
'reinit'
'open gefs_week2_precip_${dt}IC.ctl'
'set lat $south $north'
'set lon $west $east'
'set mpdraw off'
'set display color white'
'c'
'define_colors'
if($dxx>80);xl=15;endif
if($dxx<=80&$dxx>40);xl=10;endif
if($dxx<=40&$dxx>20);xl=5;endif
if($dxx<=20&$dxx>10);xl=3;endif
if($dxx<=10&$dxx>5);xl=2;endif
if($dxx<5);xl=1;endif

if($dyy>80);yl=15;endif
if($dyy<=80&$dyy>40);yl=10;endif
if($dyy<=40&$dyy>20);yl=5;endif
if($dyy<=20&$dyy>10);yl=3;endif
if($dyy<=10&$dyy>5);yl=2;endif
if($dyy<5);yl=1;endif
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
'set grads off'
'set clevs 0'
'set ccols 0'
'd total-total'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'printim blank_map.png'
'!convert -trim blank_map.png blank_map.png'
'!convert -bordercolor white -border 10 blank_map.png blank_map.png'
'quit'
eofGS

# Runs The GrADS Script
grads -bpc plot_blank_map.gs

# Moves all generated images into figures directory 
