#!/bin/bash
############################################################
# This Shell script and the embeded GrADS Script are used to
# Download CFSv2 Forecast Data for domain of your interest and
# Plots Week-2 Precip/ T2m and Circulation Anomaly Forecasts
# Written by Endalkachew Bekele, NOAA/CPC/International Desks, August 2019

LANG=en_US.utf8
unameout="$(uname -s)"

# This sets dates for target week (week-2)
if [ $unameout = "Darwin" ]; then
   wk2=`date -v -8d +%d%b`
   wkk2=`date -v -8d +%d%b%Y`
   iwk2=`date -v -8d +%Y%m%d`
   fwk2=`date -v -14d +%Y%m%d`
else
   wk2=`date --date "-8 day ago" "+%d%b"`
   wkk2=`date --date "-8 day ago" "+%d%b%Y"`
   iwk2=`date --date "-8 day ago" "+%Y%m%d"`
   fwk2=`date --date "-14 day ago" "+%Y%m%d"`
fi

if [ "$#" -ne 4 ]; then
    echo "***************************************************************************************************************************"
    echo " error while running plot_cfsv2_week2_anomalies.sh"
    echo "----------------- You need to provide 4 arguments -------------------------------------------------------------------------"
    echo "***************************************************************************************************************************"
    echo
    echo "The four arguments reflect geographical extent of your area:"
    echo
    echo "western lon, eastern lon, southern lat and northern lat in degreas, respectively"
    echo
    echo "Use negative sign for longitudes in western, and latitudes in the southern hemisphere"
    echo
    echo "For example, if your area extends from 10W to 12E and from 5S to 10N .."
    echo " you may run the script as .."
    echo
    echo " ./plot_cfsv2_week2_anomalies.sh -10 12 -5 10"
    echo
    echo
exit
fi

# This sets current date for CFSv2 data Download
dt=`date +%Y%m%d`
dtt=`date +%d%b%Y`

for var in 'precip' 't2m'; do

wget --no-check-certificate https://ftp.cpc.ncep.noaa.gov/International/subseasonal/cfsv2_week2_${var}_${dt}IC.dat

done


##### Define your domain here#####
west=$1
east=$2
south=$3
north=$4
########################333

# This extends the domain area by 1 degree for horizontal divergence calculation
let west1=$west-4
let east1=$east+4
let south1=$south-4
let north1=$north+4

let west2=$west-3
let east2=$east+3
let south2=$south-3
let north2=$north+3


# This calculates the number of grids in the zomnla and meridional directions
let dxx=$east1-$west1+1
let dyy=$north1-$south1+1


#gribmapdir=/cpc/home/ebekele/opg2/grads-2.0.1.oga.1/Contents

cat>cfsv2_week2_precip_${dt}IC.ctl<<eofctl
dset ^cfsv2_week2_precip_${dt}IC.dat
undef -999000000.000000
xdef 360 linear 0 1
ydef 181 linear -90 1
zdef 1 linear 1 1
tdef 1 linear ${dtt} 1dy
vars 4
clim 0 99 7-day climatology
total 0 99 7-day toatl Fcst
rawabv 0 99 Above Prob Raw fcst
calibabv 0 99 Above prob Calib fcst
endvars
eofctl

cat>cfsv2_week2_t2m_${dt}IC.ctl<<eofctl
dset ^cfsv2_week2_t2m_${dt}IC.dat
undef -999000000.000000
xdef 360 linear 0 1
ydef 181 linear -90 1
zdef 1 linear 1 1
tdef 1 linear ${dtt} 1dy
vars 4
clim 0 99 7-day climatology
total 0 99 7-day toatl Fcst
rawabv 0 99 Above Prob Raw fcst
calibabv 0 99 Above prob Calib fcst
endvars
eofctl

cat>cfsv2_realtime_week2_plots.gs<<eofGS
'reinit'
* Precipitation
'set mpdset hires'
'set map 1 1 6'
'gradssupp/define_colors'
'open cfsv2_week2_precip_${dt}IC.ctl'
'set lat $south1 $north1'
'set lon $west1 $east1'
* Raw Anomaly
'define prcwk2anomraw = total - clim'
* Raw, Probability of Above-Average
'define prcwk2abv = rawabv'
* Raw Probability of Below Average
'define prcwk2blw = 1 - prcwk2abv'
* Maskout for Raw Probability of Above-average
'define prcmaskabv2r = prcwk2abv - 0.50'
* Maskout for Raw Probability of below-average
'define prcmaskblw2r = prcwk2blw - 0.50'
* Calibrated, probability of above-average
'define prcprobabv2 = calibabv'
* Calibrated, probability of below-average
'define prcprobblw2 = 1 - prcprobabv2'
* Maskout for calibrated Probability of Above-average
'define prcmaskabv2c = prcprobabv2 - 0.50'
* Maskout for calibrated Probability of below-average
'define prcmaskblw2c = prcprobblw2 - 0.50'
* Daily Climatology
'define dlyclimwk2=clim/7.0'
* Dry mask (daily rainfall < 0.5mm)
'define dmaskwk2=0.5-dlyclimwk2'
'define dmskbin = const(const(maskout(dmaskwk2,dmaskwk2),1),0,-u)'
'define dmskchk = asum(dmskbin,lon=$west,lon=$east,lat=$south,lat=$north)'
'd dmskchk';res1=sublin(result,1);res2=subwrd(res1,4)

'define pabvbinr = const(const(maskout(prcmaskabv2r,prcmaskabv2r),1),0,-u)'
'define pabvchkr = asum(pabvbinr,lon=$west,lon=$east,lat=$south,lat=$north)'
'd pabvchkr';res11=sublin(result,1);res3=subwrd(res11,4)

'define pblwbinr = const(const(maskout(prcmaskblw2r,prcmaskblw2r),1),0,-u)'
'define pblwchkr = asum(pblwbinr,lon=$west,lon=$east,lat=$south,lat=$north)'
'd pblwchkr';res22=sublin(result,1);res4=subwrd(res22,4)

'define pabvbinc = const(const(maskout(prcmaskabv2c,prcmaskabv2c),1),0,-u)'
'define pabvchkc = asum(pabvbinc,lon=$west,lon=$east,lat=$south,lat=$north)'
'd pabvchkc';res33=sublin(result,1);res5=subwrd(res33,4)

'define pblwbinc = const(const(maskout(prcmaskblw2c,prcmaskblw2c),1),0,-u)'
'define pblwchkc = asum(pblwbinc,lon=$west,lon=$east,lat=$south,lat=$north)'
'd pblwchkc';res44=sublin(result,1);res6=subwrd(res44,4)
'close 1'

* 2m temperature
'open cfsv2_week2_t2m_${dt}IC.ctl'
'set lat $south1 $north1'
'set lon $west1 $east1'
* Raw Anomaly
'define t2mwk2anomraw = total - clim'
* Raw, Probability of Above-Average
'define t2mwk2abv = rawabv'
* Raw Probability of Below Average
'define t2mwk2blw = 1 - t2mwk2abv'
* Maskout for Raw Probability of Above-average
'define t2mmaskabv2r = t2mwk2abv - 0.50'
* Maskout for Raw Probability of below-average
'define t2mmaskblw2r = t2mwk2blw - 0.50'
* Calibrated, probability of above-average
'define t2mprobabv2 = calibabv'
* Calibrated, probability of below-average
'define t2mprobblw2 = 1 - t2mprobabv2'
* Maskout for calibrated Probability of Above-average
'define t2mmaskabv2c = t2mprobabv2 - 0.50'
* Maskout for calibrated Probability of below-average
'define t2mmaskblw2c = t2mprobblw2 - 0.50'

'define tabvbinr = const(const(maskout(t2mmaskabv2r,t2mmaskabv2r),1),0,-u)'
'define tabvchkr = asum(tabvbinr,lon=$west,lon=$east,lat=$south,lat=$north)'
'd tabvchkr';res55=sublin(result,1);res7=subwrd(res55,4)

'define tblwbinr = const(const(maskout(t2mmaskblw2r,t2mmaskblw2r),1),0,-u)'
'define tblwchkr = asum(tblwbinr,lon=$west,lon=$east,lat=$south,lat=$north)'
'd tblwchkr';res66=sublin(result,1);res8=subwrd(res66,4)

'define tabvbinc = const(const(maskout(t2mmaskabv2c,t2mmaskabv2c),1),0,-u)'
'define tabvchkc = asum(tabvbinc,lon=$west,lon=$east,lat=$south,lat=$north)'
'd tabvchkc';res77=sublin(result,1);res9=subwrd(res77,4)

'define tblwbinc = const(const(maskout(t2mmaskblw2c,t2mmaskblw2c),1),0,-u)'
'define tblwchkc = asum(tblwbinc,lon=$west,lon=$east,lat=$south,lat=$north)'
'd tblwchkc';res88=sublin(result,1);res10=subwrd(res88,4)

'set gxout shaded'
'set display color white'
'c'
'set gxout shaded'
if($dxx>80);xl=15;endif
if($dxx<=80&$dxx>40);xl=10;endif
if($dxx<=40&$dxx>20);xl=5;endif
if($dxx<=20&$dxx>10);xl=3;endif
if($dxx<=10&$dxx>5);xl=2;endif
if($dxx<5);xl=1;endif

if($dyy>80);yl=15;endif
if($dyy<=80&$dyy>40);yl=10;endif
if($dyy<=40&$dyy>20);yl=5;endif
if($dyy<=20&$dyy>10);yl=3;endif
if($dyy<=10&$dyy>5);yl=2;endif
if($dyy<5);yl=1;endif

* Week-2, Rainfall Anomaly
'set lat $south $north'
'set lon $west $east'
'set grads off'
'gradssupp/define_colors'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
'set clevs -50 -40 -30 -20 -10 10 20 30 40 50'
'set ccols  79 77 75 73 71 0 31 33 35 37 39'
'd prcwk2anomraw'
'gradssupp/cbarmerc2'
*'set rgb 100 225 255 255'
*'gradssupp/basemap O 100 1 M'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'q w2xy $west $north'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.25
'set string 1 c'
'set strsiz 0.18'
'draw string 4.25 'yy1' CFSv2 Week-2 Precip Anomaly'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk2} - ${fwk2}'
'printim cfsv2_week2_precip.png'
'!convert -trim cfsv2_week2_precip.png cfsv2_week2_precip.png'
'!convert -bordercolor white -border 10 cfsv2_week2_precip.png cfsv2_week2_precip.png'
'set gxout grfill'
'c'
* Week-2, Rainfall Raw
'set lat $south $north'
'set lon $west $east'
'set grads off'
'gradssupp/rgbset_brown2green2.gs'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
if(res3!=0)
'set clevs 0.50 0.55 0.60 0.70 0.80'
'set ccols  0 46 47 49 51 53'
'd maskout(prcwk2abv,prcmaskabv2r)'
'q w2xy $west $south'; y2=subwrd(result,6)
yyy2 = y2 - 0.3
yyy1 = y2 - 0.5
'gradssupp/xbar 4.3 7.80 'yyy1' 'yyy2''
endif
if(res4!=0)
'set clevs 0.50 0.55 0.60 0.70 0.80'
'set ccols 0 37 39 41 42 43'
'd maskout(prcwk2blw,prcmaskblw2r)'
'q w2xy $west $south'; y2=subwrd(result,6)
yyy2 = y2 - 0.3
yyy1 = y2 - 0.5
'gradssupp/xbar 0.50 4.00 'yyy1' 'yyy2''
endif
if(res2!=0)
'set rgb 91 235 235 235'
'set clevs 0'
'set ccols 91 91'
'd maskout(dlyclimwk2,dmaskwk2)'
endif
*'set rgb 100 225 255 255'
*'gradssupp/basemap O 100 1 M'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'q w2xy $west $north'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.25
'set string 1 c'
'set strsiz 0.18'
'draw string 4.25 'yy1' CFSv2 Week-2 Two-Category Precip Raw Forecast'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk2} - ${fwk2}'
'printim cfsv2_week2_precip_raw_prob.png'
'!convert -trim cfsv2_week2_precip_raw_prob.png cfsv2_week2_precip_raw_prob.png'
'!convert -bordercolor white -border 10 cfsv2_week2_precip_raw_prob.png cfsv2_week2_precip_raw_prob.png'
'c'
* Week-2, Rainfall Reg. Calib.
'set lat $south $north'
'set lon $west $east'
'set grads off'
'gradssupp/rgbset_brown2green2.gs'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
if(res5!=0)
'set clevs 0.50 0.55 0.60 0.70 0.80'
'set ccols  0 46 47 49 51 53'
'd maskout(prcprobabv2,prcmaskabv2c)'
'q w2xy $west $south'; y2=subwrd(result,6)
yyy2 = y2 - 0.3
yyy1 = y2 - 0.5
'gradssupp/xbar 4.3 7.80 'yyy1' 'yyy2''
endif
if(res6!=0)
'set clevs 0.50 0.55 0.60 0.70 0.80'
'set ccols 0 37 39 41 42 43'
'd maskout(prcprobblw2,prcmaskblw2c)'
'q w2xy $west $south'; y2=subwrd(result,6)
yyy2 = y2 - 0.3
yyy1 = y2 - 0.5
'gradssupp/xbar 0.50 4.00 'yyy1' 'yyy2''
endif
if(res2!=0)
'set rgb 91 235 235 235'
'set clevs 0'
'set ccols 91 91'
'd maskout(dlyclimwk2,dmaskwk2)'
endif
*'set rgb 100 225 255 255'
*'gradssupp/basemap O 100 1 M'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'q w2xy $west $north'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.25
'set string 1 c'
'set strsiz 0.18'
'draw string 4.25 'yy1' CFSv2 Week-2 Two-Category Precip Reg. Calib. Forecast'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk2} - ${fwk2}'
'printim cfsv2_week2_precip_calib_prob.png'
'!convert -trim cfsv2_week2_precip_calib_prob.png cfsv2_week2_precip_calib_prob.png'
'!convert -bordercolor white -border 10 cfsv2_week2_precip_calib_prob.png cfsv2_week2_precip_calib_prob.png'
'c'
'set gxout shaded'
* Week-2, Temperature Anomaly
'set grads off'
'gradssupp/define_colors'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
'set clevs -3.0 -2.0 -1.5 -1.0 -0.5 0.5 1.0 1.5 2.0 3.0'
'set ccols  49 47 45 43 41 0 21 23 25 27 29'
'd t2mwk2anomraw'
'gradssupp/cbarmerc2'
*'set rgb 100 225 255 255'
*'gradssupp/basemap O 100 1 M'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'q w2xy $west $north'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.25
'set string 1 c'
'set strsiz 0.18'
'draw string 4.25 'yy1' CFSv2 Week-2 T2m Anomaly'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk2} - ${fwk2}'
'printim cfsv2_week2_t2m.png'
'!convert -trim cfsv2_week2_t2m.png cfsv2_week2_t2m.png'
'!convert -bordercolor white -border 10 cfsv2_week2_t2m.png cfsv2_week2_t2m.png'
'c'
'set gxout grfill'
* Week-2, Temperature Raw
'set grads off'
'gradssupp/rgbset_blue2red2.gs'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
if(res7!=0)
'set clevs 0.50 0.55 0.60 0.70 0.80'
'set ccols  0 21 22 23 24 25'
'd maskout(t2mwk2abv,t2mmaskabv2r)'
'q w2xy $west $south'; y2=subwrd(result,6)
yyy2 = y2 - 0.3
yyy1 = y2 - 0.5
'gradssupp/xbar 4.3 7.80 'yyy1' 'yyy2''
endif
if(res8!=0)
'set clevs 0.50 0.55 0.60 0.70 0.80'
'set ccols 0 20 19 18 17 16'
'd maskout(t2mwk2blw,t2mmaskblw2r)'
'q w2xy $west $south'; y2=subwrd(result,6)
yyy2 = y2 - 0.3
yyy1 = y2 - 0.5
'gradssupp/xbar 4.3 7.80 'yyy1' 'yyy2''
endif
*'set rgb 100 225 255 255'
*'gradssupp/basemap O 100 1 M'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'q w2xy $west $north'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.25
'set string 1 c'
'set strsiz 0.18'
'draw string 4.25 'yy1' CFSv2 Week-2 Two-Category T2m Raw Forecast'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk2} - ${fwk2}'
'printim cfsv2_week2_t2m_raw_prob.png'
'!convert -trim cfsv2_week2_t2m_raw_prob.png cfsv2_week2_t2m_raw_prob.png'
'!convert -bordercolor white -border 10 cfsv2_week2_t2m_raw_prob.png cfsv2_week2_t2m_raw_prob.png'
'c'
* Week-2, T2m Calibrated
'set lat $south $north'
'set lon $west $east'
'set grads off'
'gradssupp/rgbset_blue2red2.gs'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
if(res9!=0)
'set clevs 0.50 0.55 0.60 0.70 0.80'
'set ccols  0 21 22 23 24 25'
'd maskout(t2mprobabv2,t2mmaskabv2c)'
'q w2xy $west $south'; y2=subwrd(result,6)
yyy2 = y2 - 0.3
yyy1 = y2 - 0.5
'gradssupp/xbar 4.3 7.80 'yyy1' 'yyy2''
endif
if(res10!=0)
'set clevs 0.50 0.55 0.60 0.70 0.80'
'set ccols 0 20 19 18 17 16'
'd maskout(t2mprobblw2,t2mmaskblw2c)'
'q w2xy $west $south'; y2=subwrd(result,6)
yyy2 = y2 - 0.3
yyy1 = y2 - 0.5
'gradssupp/xbar 0.50 4.00 'yyy1' 'yyy2''
endif
*'set rgb 100 225 255 255'
*'gradssupp/basemap O 100 1 M'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'q w2xy $west $north'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.25
'set string 1 c'
'set strsiz 0.18'
'draw string 4.25 'yy1' CFSv2 Week-2 Two-Category T2m Reg. Calib. Forecast'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk2} - ${fwk2}'
'printim cfsv2_week2_t2m_calib_prob.png'
'!convert -trim cfsv2_week2_t2m_calib_prob.png cfsv2_week2_t2m_calib_prob.png'
'!convert -bordercolor white -border 10 cfsv2_week2_t2m_calib_prob.png cfsv2_week2_t2m_calib_prob.png'
'quit'
eofGS

# Runs The GrADS Script
grads -bpc cfsv2_realtime_week2_plots.gs

# Moves all generated images into figures directory 
mv *.png cfsv2_week2_figures/
