#!/bin/bash
############################################################
# This Shell script and the embeded GrADS Script are used to
# Download GEFS Forecast Data for domain of your interest and
# Plots Week-1 Precip/ T2m and Circulation Anomaly Forecasts
# Written by Endalkachew Bekele, NOAA/CPC/International Desks, August 2019

LANG=en_US.utf8
unameout="$(uname -s)"

# This sets dates for target week (week-1)
if [ $unameout = "Darwin" ]; then
   wk1=`date -v -1d +%d%b`
   wkk1=`date -v -1d +%d%b%Y`
   iwk1=`date -v -1d +%Y%m%d`
   fwk1=`date -v -7d +%Y%m%d`
else
   wk1=`date --date "-1 day ago" "+%d%b"`
   wkk1=`date --date "-1 day ago" "+%d%b%Y"`
   iwk1=`date --date "-1 day ago" "+%Y%m%d"`
   fwk1=`date --date "-7 day ago" "+%Y%m%d"`
fi

if [ "$#" -ne 4 ]; then
    echo "***************************************************************************************************************************"
    echo " error while running plot_gefs_week1_anomalies.sh"
    echo "----------------- You need to provide 4 arguments -------------------------------------------------------------------------"
    echo "***************************************************************************************************************************"
    echo
    echo "The four arguments reflect geographical extent of your area:"
    echo
    echo "western lon, eastern lon, southern lat and northern lat in degreas, respectively"
    echo
    echo "Use negative sign for longitudes in western, and latitudes in the southern hemisphere"
    echo
    echo "For example, if your area extends from 10W to 12E and from 5S to 10N .."
    echo " you may run the script as .."
    echo
    echo " ./plot_gefs_week1_anomalies.sh -10 12 -5 10"
    echo
    echo
exit
fi

# This sets current date for GEFS data Download
dt=`date +%Y%m%d`
dtt=`date +%d%b%Y`

for var in 'wind' 'precip' 't2m'; do

wget --no-check-certificate https://ftp.cpc.ncep.noaa.gov/International/subseasonal/gefs_week1_${var}_${dt}IC.dat

done


##### Define your domain here#####
west=$1
east=$2
south=$3
north=$4
########################333

# This extends the domain area by 1 degree for horizontal divergence calculation
let west1=$west-4
let east1=$east+4
let south1=$south-4
let north1=$north+4

let west2=$west-3
let east2=$east+3
let south2=$south-3
let north2=$north+3


# This calculates the number of grids in the zomnla and meridional directions
let dxx=$east1-$west1+1
let dyy=$north1-$south1+1


cat>gefs_week1_wind_${dt}IC.ctl<<eofctl
dset ^gefs_week1_wind_${dt}IC.dat
undef -999000000.000000
xdef 360 linear 0 1
ydef 181 linear -90 1
zdef 1 linear 1 1
tdef 1 linear ${dtt} 1dy
vars 8
u850mb 0 99 u wind 850mb
v850mb 0 99 v wind 850mb
u700mb 0 99 u wind 700mb
v700mb 0 99 v wind 700mb
u500mb 0 99 u wind 500mb
v500mb 0 99 v wind 500mb
u200mb 0 99 u wind 200mb
v200mb 0 99 v wind 200mb
endvars
eofctl

cat>gefs_week1_precip_${dt}IC.ctl<<eofctl
dset ^gefs_week1_precip_${dt}IC.dat
undef -999000000.000000
xdef 360 linear 0 1
ydef 181 linear -90 1
zdef 1 linear 1 1
tdef 1 linear ${dtt} 1dy
vars 7
clim 0 99 7-day climatology
total 0 99 7-day toatl Fcst
rawabv 0 99 Above Prob Raw fcst
calibabv 0 99 Above prob Calib fcst
prob25 0 99 Exccedance prob 25mm
prob50 0 99 Exccedance prob 50mm
prob100 0 99 Exccedance prob 100mm
endvars
eofctl

cat>gefs_week1_t2m_${dt}IC.ctl<<eofctl
dset ^gefs_week1_t2m_${dt}IC.dat
undef -999000000.000000
xdef 360 linear 0 1
ydef 181 linear -90 1
zdef 1 linear 1 1
tdef 1 linear ${dtt} 1dy
vars 4
clim 0 99 7-day climatology
total 0 99 7-day toatl Fcst
rawabv 0 99 Above Prob Raw fcst
calibabv 0 99 Above prob Calib fcst
endvars
eofctl

cat>gefs_realtime_week1_plots.gs<<eofGS
'reinit'
'open gefs_week1_wind_${dt}IC.ctl'
'set lat $south1 $north1'
'set lon $west1 $east1'

* Calculates Horizontal Divergence

'define u850wk1anom = u850mb'
'define v850wk1anom = v850mb'
'define u700wk1anom = u700mb'
'define v700wk1anom = v700mb'
'define u500wk1anom = u500mb'
'define v500wk1anom = v500mb'
'define u200wk1anom = u200mb'
'define v200wk1anom = v200mb'

'define wk1850divanom = hdivg(u850wk1anom,v850wk1anom)*1e05'
'define wk1700divanom = hdivg(u700wk1anom,v700wk1anom)*1e05'
'define wk1500divanom = hdivg(u500wk1anom,v500wk1anom)*1e05'
'define wk1200divanom = hdivg(u200wk1anom,v200wk1anom)*1e05'
'close 1'
* Precipitation
'set mpdset hires'
'set map 1 1 6'
'gradssupp/define_colors'
'open gefs_week1_precip_${dt}IC.ctl'
'set lat $south1 $north1'
'set lon $west1 $east1'
* Raw Anomaly
'define prcwk1anomraw = total - clim'
* Raw, Probability of Above-Average
'define prcwk1abv = rawabv'
* Raw Probability of Below Average
'define prcwk1blw = 1 - prcwk1abv'
* Maskout for Raw Probability of Above-average
'define prcmaskabv1r = prcwk1abv - 0.50'
* Maskout for Raw Probability of below-average
'define prcmaskblw1r = prcwk1blw - 0.50'
* Calibrated, probability of above-average
'define prcprobabv1 = calibabv'
* Calibrated, probability of below-average
'define prcprobblw1 = 1 - prcprobabv1'
* Maskout for calibrated Probability of Above-average
'define prcmaskabv1c = prcprobabv1 - 0.50'
* Maskout for calibrated Probability of below-average
'define prcmaskblw1c = prcprobblw1 - 0.50'
* Probability of Exceedance
'define prob25wk1 = prob25'
'define prob50wk1 = prob50'
'define prob100wk1 = prob100'
* Daily Climatology
'define dlyclimwk1=clim/7.0'
* Dry mask (daily rainfall < 0.5mm)
'define dmaskwk1=0.5-dlyclimwk1'
'define dmskbin = const(const(maskout(dmaskwk1,dmaskwk1),1),0,-u)'
'define dmskchk = asum(dmskbin,lon=$west,lon=$east,lat=$south,lat=$north)'
'd dmskchk';res1=sublin(result,1);res2=subwrd(res1,4)

'define pabvbinr = const(const(maskout(prcmaskabv1r,prcmaskabv1r),1),0,-u)'
'define pabvchkr = asum(pabvbinr,lon=$west,lon=$east,lat=$south,lat=$north)'
'd pabvchkr';res11=sublin(result,1);res3=subwrd(res11,4)

'define pblwbinr = const(const(maskout(prcmaskblw1r,prcmaskblw1r),1),0,-u)'
'define pblwchkr = asum(pblwbinr,lon=$west,lon=$east,lat=$south,lat=$north)'
'd pblwchkr';res22=sublin(result,1);res4=subwrd(res22,4)

'define pabvbinc = const(const(maskout(prcmaskabv1c,prcmaskabv1c),1),0,-u)'
'define pabvchkc = asum(pabvbinc,lon=$west,lon=$east,lat=$south,lat=$north)'
'd pabvchkc';res33=sublin(result,1);res5=subwrd(res33,4)

'define pblwbinc = const(const(maskout(prcmaskblw1c,prcmaskblw1c),1),0,-u)'
'define pblwchkc = asum(pblwbinc,lon=$west,lon=$east,lat=$south,lat=$north)'
'd pblwchkc';res44=sublin(result,1);res6=subwrd(res44,4)

'close 1'

* 2m temperature
'open gefs_week1_t2m_${dt}IC.ctl'
'set lat $south1 $north1'
'set lon $west1 $east1'
* Raw Anomaly
'define t2mwk1anomraw = total - clim'
* Raw, Probability of Above-Average
'define t2mwk1abv = rawabv'
* Raw Probability of Below Average
'define t2mwk1blw = 1 - t2mwk1abv'
* Maskout for Raw Probability of Above-average
'define t2mmaskabv1r = t2mwk1abv - 0.50'
* Maskout for Raw Probability of below-average
'define t2mmaskblw1r = t2mwk1blw - 0.50'
* Calibrated, probability of above-average
'define t2mprobabv1 = calibabv'
* Calibrated, probability of below-average
'define t2mprobblw1 = 1 - t2mprobabv1'
* Maskout for calibrated Probability of Above-average
'define t2mmaskabv1c = t2mprobabv1 - 0.50'
* Maskout for calibrated Probability of below-average
'define t2mmaskblw1c = t2mprobblw1 - 0.50'

'define tabvbinr = const(const(maskout(t2mmaskabv1r,t2mmaskabv1r),1),0,-u)'
'define tabvchkr = asum(tabvbinr,lon=$west,lon=$east,lat=$south,lat=$north)'
'd tabvchkr';res55=sublin(result,1);res7=subwrd(res55,4)

'define tblwbinr = const(const(maskout(t2mmaskblw1r,t2mmaskblw1r),1),0,-u)'
'define tblwchkr = asum(tblwbinr,lon=$west,lon=$east,lat=$south,lat=$north)'
'd tblwchkr';res66=sublin(result,1);res8=subwrd(res66,4)

'define tabvbinc = const(const(maskout(t2mmaskabv1c,t2mmaskabv1c),1),0,-u)'
'define tabvchkc = asum(tabvbinc,lon=$west,lon=$east,lat=$south,lat=$north)'
'd tabvchkc';res77=sublin(result,1);res9=subwrd(res77,4)

'define tblwbinc = const(const(maskout(t2mmaskblw1c,t2mmaskblw1c),1),0,-u)'
'define tblwchkc = asum(tblwbinc,lon=$west,lon=$east,lat=$south,lat=$north)'
'd tblwchkc';res88=sublin(result,1);res10=subwrd(res88,4)

'set gxout shaded'
'set display color white'
'c'
'set gxout shaded'
if($dxx>80);xl=15;endif
if($dxx<=80&$dxx>40);xl=10;endif
if($dxx<=40&$dxx>20);xl=5;endif
if($dxx<=20&$dxx>10);xl=3;endif
if($dxx<=10&$dxx>5);xl=2;endif
if($dxx<5);xl=1;endif

if($dyy>80);yl=15;endif
if($dyy<=80&$dyy>40);yl=10;endif
if($dyy<=40&$dyy>20);yl=5;endif
if($dyy<=20&$dyy>10);yl=3;endif
if($dyy<=10&$dyy>5);yl=2;endif
if($dyy<5);yl=1;endif

* Week-1, 850-hPa Wind Anomaly
'set lat $south2 $north2'
'set lon $west2 $east2'
'set mpdset hires'
'set map 1 1 6'
'gradssupp/define_colors'
'set display color white'
'c'
'set gxout shaded'
'set grads off'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
'set clevs -1.5 -1.0 -0.5 -0.25 0.25 0.5 1.0 1.5'
'set ccols 48 46 44 42 0 72 74 76 78'
'd wk1850divanom'
'd skip(u850wk1anom,2,2);v850wk1anom'
'gradssupp/cbarmerc2.gs'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'set string 1 c'
'set strsiz 0.18'
'q w2xy $west2 $north2'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.3
'draw string 4.25 'yy1' GEFS Week-1 850-hPa Divergence and Wind Anomaly'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk1} - ${fwk1}'
'printim gefs_week1_850_wind_div.png'
'!convert -trim gefs_week1_850_wind_div.png gefs_week1_850_wind_div.png'
'!convert -bordercolor white -border 10 gefs_week1_850_wind_div.png gefs_week1_850_wind_div.png'
'c'
* Week-1, 700-hPa Wind Anomaly
'set lat $south2 $north2'
'set lon $west2 $east2'
'set mpdset hires'
'set map 1 1 6'
'gradssupp/define_colors'
'set display color white'
'c'
'set gxout shaded'
'set grads off'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
'set clevs -1.5 -1.0 -0.5 -0.25 0.25 0.5 1.0 1.5'
'set ccols 48 46 44 42 0 72 74 76 78'
'd wk1700divanom'
'd skip(u700wk1anom,2,2);v700wk1anom'
'gradssupp/cbarmerc2.gs'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'set string 1 c'
'set strsiz 0.18'
'q w2xy $west2 $north2'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.3
'draw string 4.25 'yy1' GEFS Week-1 700-hPa Divergence and Wind Anomaly'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk1} - ${fwk1}'
'printim gefs_week1_700_wind_div.png'
'!convert -trim gefs_week1_700_wind_div.png gefs_week1_700_wind_div.png'
'!convert -bordercolor white -border 10 gefs_week1_700_wind_div.png gefs_week1_700_wind_div.png'
'c'
* Week-1, 500-hPa Wind Anomaly
'set lat $south2 $north2'
'set lon $west2 $east2'
'set mpdset hires'
'set map 1 1 6'
'gradssupp/define_colors'
'set display color white'
'c'
'set gxout shaded'
'set grads off'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
'set clevs -1.5 -1.0 -0.5 -0.25 0.25 0.5 1.0 1.5'
'set ccols 48 46 44 42 0 72 74 76 78'
'd wk1500divanom'
'd skip(u500wk1anom,2,2);v500wk1anom'
'gradssupp/cbarmerc2.gs'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'set string 1 c'
'set strsiz 0.18'
'q w2xy $west2 $north2'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.3
'draw string 4.25 'yy1' GEFS Week-1 500-hPa Divergence and Wind Anomaly'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk1} - ${fwk1}'
'printim gefs_week1_500_wind_div.png'
'!convert -trim gefs_week1_500_wind_div.png gefs_week1_500_wind_div.png'
'!convert -bordercolor white -border 10 gefs_week1_500_wind_div.png gefs_week1_500_wind_div.png'
'c'
* Week-1, 200-hPa Wind Anomaly
'set grads off'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
'set clevs -1.5 -1.0 -0.5 -0.25 0.25 0.5 1.0 1.5'
'set ccols 78 76 74 72 0 42 44 46 48'
'd wk1200divanom'
'd skip(u200wk1anom,2,2);v200wk1anom'
'gradssupp/cbarmerc2.gs'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'set string 1 c'
'set strsiz 0.18'
'q w2xy $west2 $north2'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.3
'draw string 4.25 'yy1' GEFS Week-1 200-hPa Divergence and Wind Anomaly'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk1} - ${fwk1}'
'printim gefs_week1_200_wind_div.png'
'!convert -trim gefs_week1_200_wind_div.png gefs_week1_200_wind_div.png'
'!convert -bordercolor white -border 10 gefs_week1_200_wind_div.png gefs_week1_200_wind_div.png'
'c'
* Week-1, Rainfall Anomaly
'set lat $south $north'
'set lon $west $east'
'set grads off'
'gradssupp/define_colors'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
'set clevs -50 -40 -30 -20 -10 10 20 30 40 50'
'set ccols  79 77 75 73 71 0 31 33 35 37 39'
'd prcwk1anomraw'
'gradssupp/cbarmerc2'
*'set rgb 100 225 255 255'
*'gradssupp/basemap O 100 1 M'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'q w2xy $west $north'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.25
'set string 1 c'
'set strsiz 0.18'
'draw string 4.25 'yy1' GEFS Week-1 Precip Anomaly'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk1} - ${fwk1}'
'printim gefs_week1_precip.png'
'!convert -trim gefs_week1_precip.png gefs_week1_precip.png'
'!convert -bordercolor white -border 10 gefs_week1_precip.png gefs_week1_precip.png'
'set gxout grfill'
'c'
* Week-1, Rainfall Raw
'set lat $south $north'
'set lon $west $east'
'set grads off'
'gradssupp/rgbset_brown2green2.gs'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
if(res3!=0)
'set clevs 0.50 0.55 0.60 0.70 0.80'
'set ccols  0 46 47 49 51 53'
'd maskout(prcwk1abv,prcmaskabv1r)'
'q w2xy $west $south'; y2=subwrd(result,6)
yyy2 = y2 - 0.3
yyy1 = y2 - 0.5
'gradssupp/xbar 4.3 7.80 'yyy1' 'yyy2''
endif
if(res4!=0)
'set clevs 0.50 0.55 0.60 0.70 0.80'
'set ccols 0 37 39 41 42 43'
'd maskout(prcwk1blw,prcmaskblw1r)'
'q w2xy $west $south'; y2=subwrd(result,6)
yyy2 = y2 - 0.3
yyy1 = y2 - 0.5
'gradssupp/xbar 0.50 4.00 'yyy1' 'yyy2''
endif
if(res2!=0)
'set rgb 91 235 235 235'
'set clevs 0'
'set ccols 91 91'
'd maskout(dlyclimwk1,dmaskwk1)'
endif
*'set rgb 100 225 255 255'
*'gradssupp/basemap O 100 1 M'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'q w2xy $west $north'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.25
'set string 1 c'
'set strsiz 0.18'
'draw string 4.25 'yy1' GEFS Week-1 Two-Category Precip Raw Forecast'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk1} - ${fwk1}'
'printim gefs_week1_precip_raw_prob.png'
'!convert -trim gefs_week1_precip_raw_prob.png gefs_week1_precip_raw_prob.png'
'!convert -bordercolor white -border 10 gefs_week1_precip_raw_prob.png gefs_week1_precip_raw_prob.png'
'c'
* Week-1, Rainfall Reg. Calib.
'set lat $south $north'
'set lon $west $east'
'set grads off'
'gradssupp/rgbset_brown2green2.gs'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
if(res5!=0)
'set clevs 0.50 0.55 0.60 0.70 0.80'
'set ccols  0 46 47 49 51 53'
'd maskout(prcprobabv1,prcmaskabv1c)'
'q w2xy $west $south'; y2=subwrd(result,6)
yyy2 = y2 - 0.3
yyy1 = y2 - 0.5
'gradssupp/xbar 4.3 7.80 'yyy1' 'yyy2''
endif
if(res6!=0)
'set clevs 0.50 0.55 0.60 0.70 0.80'
'set ccols 0 37 39 41 42 43'
'd maskout(prcprobblw1,prcmaskblw1c)'
'q w2xy $west $south'; y2=subwrd(result,6)
yyy2 = y2 - 0.3
yyy1 = y2 - 0.5
'gradssupp/xbar 0.50 4.00 'yyy1' 'yyy2''
endif
if(res2!=0)
'set rgb 91 235 235 235'
'set clevs 0'
'set ccols 91 91'
'd maskout(dlyclimwk1,dmaskwk1)'
endif
*'set rgb 100 225 255 255'
*'gradssupp/basemap O 100 1 M'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'q w2xy $west $north'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.25
'set string 1 c'
'set strsiz 0.18'
'draw string 4.25 'yy1' GEFS Week-1 Two-Category Precip Reg. Calib. Forecast'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk1} - ${fwk1}'
'printim gefs_week1_precip_calib_prob.png'
'!convert -trim gefs_week1_precip_calib_prob.png gefs_week1_precip_calib_prob.png'
'!convert -bordercolor white -border 10 gefs_week1_precip_calib_prob.png gefs_week1_precip_calib_prob.png'
'c'
'set gxout shaded'
* Week-1, Rainfall Exceedance Probability (>25mm)
'set grads off'
'gradssupp/define_colors'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
'set clevs 5 10 20 30 40 50 60 70 80 90 95'
'set ccols 0 31 33 35 37 39 43 22 24 26 28 68 69'
'd prob25wk1*100'
'gradssupp/cbarmerc2'
*'set rgb 100 225 255 255'
*'gradssupp/basemap O 100 1 M'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'set string 1 c'
'set strsiz 0.18'
'q w2xy $west $north'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.3
'draw string 4.25 'yy1' GEFS Week-1 Exceedance Prob. > 25mm'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk1} - ${fwk1}'
'printim gefs_week1_prob_25.png'
'!convert -trim gefs_week1_prob_25.png gefs_week1_prob_25.png'
'!convert -bordercolor white -border 10 gefs_week1_prob_25.png gefs_week1_prob_25.png'
'c'
* Week-1, Rainfall Exceedance Probability (>50mm)
'set grads off'
'gradssupp/define_colors'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
'set clevs 5 10 20 30 40 50 60 70 80 90 95'
'set ccols 0 31 33 35 37 39 43 22 24 26 28 68 69'
'd prob50wk1*100'
'gradssupp/cbarmerc2'
*'set rgb 100 225 255 255'
*'gradssupp/basemap O 100 1 M'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'set string 1 c'
'set strsiz 0.18'
'q w2xy $west $north'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.3
'draw string 4.25 'yy1' GEFS Week-1 Exceedance Prob. > 50mm'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk1} - ${fwk1}'
'printim gefs_week1_prob_50.png'
'!convert -trim gefs_week1_prob_50.png gefs_week1_prob_50.png'
'!convert -bordercolor white -border 10 gefs_week1_prob_50.png gefs_week1_prob_50.png'
'c'
* Week-1, Rainfall Exceedance Probability (>100mm)
'set grads off'
'gradssupp/define_colors'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
'set clevs 5 10 20 30 40 50 60 70 80 90 95'
'set ccols 0 31 33 35 37 39 43 22 24 26 28 68 69'
'd prob100wk1*100'
'gradssupp/cbarmerc2'
*'set rgb 100 225 255 255'
*'gradssupp/basemap O 100 1 M'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'set string 1 c'
'set strsiz 0.18'
'q w2xy $west $north'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.3
'draw string 4.25 'yy1' GEFS Week-1 Exceedance Prob. > 100mm'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk1} - ${fwk1}'
'printim gefs_week1_prob_100.png'
'!convert -trim gefs_week1_prob_100.png gefs_week1_prob_100.png'
'!convert -bordercolor white -border 10 gefs_week1_prob_100.png gefs_week1_prob_100.png'
'c'
* Week-1, Temperature Anomaly
'set grads off'
'gradssupp/define_colors'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
'set clevs -3.0 -2.0 -1.5 -1.0 -0.5 0.5 1.0 1.5 2.0 3.0'
'set ccols  49 47 45 43 41 0 21 23 25 27 29'
'd t2mwk1anomraw'
'gradssupp/cbarmerc2'
*'set rgb 100 225 255 255'
*'gradssupp/basemap O 100 1 M'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'q w2xy $west $north'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.25
'set string 1 c'
'set strsiz 0.18'
'draw string 4.25 'yy1' GEFS Week-1 T2m Anomaly'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk1} - ${fwk1}'
'printim gefs_week1_t2m.png'
'!convert -trim gefs_week1_t2m.png gefs_week1_t2m.png'
'!convert -bordercolor white -border 10 gefs_week1_t2m.png gefs_week1_t2m.png'
'c'
'set gxout grfill'
* Week-1, Temperature Raw
'set grads off'
'gradssupp/rgbset_blue2red2.gs'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
if(res7!=0)
'set clevs 0.50 0.55 0.60 0.70 0.80'
'set ccols  0 21 22 23 24 25'
'd maskout(t2mwk1abv,t2mmaskabv1r)'
'q w2xy $west $south'; y2=subwrd(result,6)
yyy2 = y2 - 0.3
yyy1 = y2 - 0.5
'gradssupp/xbar 4.3 7.80 'yyy1' 'yyy2''
endif
if(res8!=0)
'set clevs 0.50 0.55 0.60 0.70 0.80'
'set ccols 0 20 19 18 17 16'
'd maskout(t2mwk1blw,t2mmaskblw1r)'
'q w2xy $west $south'; y2=subwrd(result,6)
yyy2 = y2 - 0.3
yyy1 = y2 - 0.5
'gradssupp/xbar 0.50 4.00 'yyy1' 'yyy2''
endif
*'set rgb 100 225 255 255'
*'gradssupp/basemap O 100 1 M'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'q w2xy $west $north'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.25
'set string 1 c'
'set strsiz 0.18'
'draw string 4.25 'yy1' GEFS Week-1 Two-Category T2m Raw Forecast'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk1} - ${fwk1}'
'printim gefs_week1_t2m_raw_prob.png'
'!convert -trim gefs_week1_t2m_raw_prob.png gefs_week1_t2m_raw_prob.png'
'!convert -bordercolor white -border 10 gefs_week1_t2m_raw_prob.png gefs_week1_t2m_raw_prob.png'
'c'
* Week-1, T2m Calibrated
'set lat $south $north'
'set lon $west $east'
'set grads off'
'gradssupp/rgbset_blue2red2.gs'
'set xlint 'xl''
'set ylint 'yl''
'set xlopts 1 6 0.15'
'set ylopts 1 6 0.15'
if(res9!=0)
'set clevs 0.50 0.55 0.60 0.70 0.80'
'set ccols  0 21 22 23 24 25'
'd maskout(t2mprobabv1,t2mmaskabv1c)'
'q w2xy $west $south'; y2=subwrd(result,6)
yyy2 = y2 - 0.3
yyy1 = y2 - 0.5
'gradssupp/xbar 4.3 7.80 'yyy1' 'yyy2''
endif
if(res10!=0)
'set clevs 0.50 0.55 0.60 0.70 0.80'
'set ccols 0 20 19 18 17 16'
'd maskout(t2mprobblw1,t2mmaskblw1c)'
'q w2xy $west $south'; y2=subwrd(result,6)
yyy2 = y2 - 0.3
yyy1 = y2 - 0.5
'gradssupp/xbar 0.50 4.00 'yyy1' 'yyy2''
endif
*'set rgb 100 225 255 255'
*'gradssupp/basemap O 100 1 M'
'set line 1 1 6'
'draw shp gradssupp/WMO_basemap.shp'
'q w2xy $west $north'; y1=subwrd(result,6)
yy1 = y1 + 0.6
yy2 = y1 + 0.25
'set string 1 c'
'set strsiz 0.18'
'draw string 4.25 'yy1' GEFS Week-1 Two-Category T2m Reg. Calib. Forecast'
'set strsiz 0.16'
'draw string 4.25 'yy2' Valid: ${iwk1} - ${fwk1}'
'printim gefs_week1_t2m_calib_prob.png'
'!convert -trim gefs_week1_t2m_calib_prob.png gefs_week1_t2m_calib_prob.png'
'!convert -bordercolor white -border 10 gefs_week1_t2m_calib_prob.png gefs_week1_t2m_calib_prob.png'
'quit'
eofGS

# Runs The GrADS Script
grads -bpc gefs_realtime_week1_plots.gs

# Moves all generated images into figures directory 
mv *.png gefs_week1_figures/
